#include <u.h>
#include <libc.h>
#include <thread.h>
#include "usb.h"
#include "wacom.h"

typedef struct Parg Parg;

enum
{
	Ndevs = 10,
	Arglen = 80,
	Nargs = 10,
};

static void
usage(void)
{
	fprint(2, "usage: %s [-bdkm] [-a n] [-N nb] [dev...]\n", argv0);
	threadexitsall("usage");
}

static int
matchcinfo(char *info, void *a)
{
	Cinfo *ip;
	char buf[50];

	for(ip = a; ip->vid != 0; ip++){
		snprint(buf, sizeof(buf), "vid %#06x did %#06x", ip->vid, ip->did);
		if(strstr(info, buf) != nil)
			return 0;
	}
	return -1;
}

void
threadmain(int argc, char **argv)
{
	char args[Arglen];
	char *as, *ae;
	int accel, devid;

	quotefmtinstall();
	ae = args+sizeof(args);
	as = seprint(args, ae, "kb");
	ARGBEGIN{
	case 'a':
		accel = strtol(EARGF(usage()), nil, 0);
		as = seprint(as, ae, " -a %d", accel);
		break;
	case 'd':
		usbdebug++;
		as = seprint(as, ae, " -d");
		break;
	case 'N':
		devid = atoi(EARGF(usage()));		/* ignore dev number */
		USED(devid);
		break;
	default:
		usage();
	}ARGEND;

	rfork(RFNOTEG);
	fmtinstall('U', Ufmt);
	threadsetgrp(threadid());
	startdevs(args, argv, argc, matchcinfo, wacominfo, wacommain);
	threadexits(nil);
}
